@@ -7,6 +7,7 @@ import json
 import zipfile  # 确保在顶部导入
 import shutil
 import glob  # 用于日志文件管理
+from urllib.parse import quote  # 用于URL编码文件名
 from flask_cors import CORS  # 导入 CORS
 from datetime import datetime, time
 from io import BytesIO
@@ -66,9 +67,9 @@ template_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'templat
 static_dir = template_dir  # 将static也指向templates目录
 
 app = Flask(__name__, template_folder=template_dir, static_folder=static_dir)
-# 启用 CORS
+# 启用 CORS，并暴露Content-Disposition头供前端JavaScript访问
 # CORS(app, origins="http://localhost:5500")  # 允许来自 http://localhost:5500 的请求
-CORS(app, origins="*") 
+CORS(app, origins="*", expose_headers=["Content-Disposition"]) 
 
 # 配置详细的日志
 # 从环境变量获取日志目录，如果没有设置则使用默认位置
@@ -279,29 +280,35 @@ def process_file():
                 logger.info(f"返回单个文件: {output_file}, 大小: {os.path.getsize(output_file)} 字节")
                 # 使用Flask的send_file函数而不是send_from_directory来确保正确下载
                 try:
-                    # 创建一个仅包含 latin-1 编码的文件名
-                    safe_filename = os.path.basename(output_file)
-                    # 如果文件名包含非 latin-1 编码字符，使用时间戳生成一个安全的文件名
-                    # 这是由于 Anaconda\Lib\http\server.py 默认使用 latin-1 编码
-                    try:
-                        safe_filename.encode('latin-1')
-                    except UnicodeEncodeError:
-                        # 提取扩展名
-                        _, ext = os.path.splitext(safe_filename)
-                        # 生成基于时间戳的安全文件名
-                        safe_filename = f"output_{datetime.now().strftime('%Y%m%d_%H%M%S')}{ext}"
-                        logger.info(f"使用安全文件名: {safe_filename}")
+                    # 获取原始文件名
+                    original_filename = os.path.basename(output_file)
                     
                     response = send_file(
                         output_file,
                         as_attachment=True,
-                        download_name=safe_filename,
+                        download_name=original_filename,
                         mimetype='application/octet-stream'
                     )
-                    # 添加额外的响应头，强制浏览器下载
-                    response.headers["Content-Disposition"] = f"attachment; filename={safe_filename}"
+                    # 设置Content-Disposition，兼容所有浏览器
+                    # 参考: https://www.cnblogs.com/PengZhao-Mr/p/18489371
+                    try:
+                        # 检查文件名是否只包含ASCII字符
+                        original_filename.encode('ascii')
+                        response.headers["Content-Disposition"] = f'attachment; filename="{original_filename}"'
+                        logger.info(f"文件名使用ASCII编码: {original_filename}")
+                    except UnicodeEncodeError:
+                        # 包含中文，使用RFC 2231标准格式
+                        # filename*=UTF-8''编码后的文件名
+                        encoded_filename = quote(original_filename)
+                        response.headers["Content-Disposition"] = f"attachment; filename*=UTF-8''{encoded_filename}"
+                        logger.info(f"设置UTF-8编码文件名: {encoded_filename}")
+                    
                     response.headers["Content-Type"] = "application/octet-stream"
                     response.headers["X-Content-Type-Options"] = "nosniff"
+                    # 确保前端JavaScript可以访问Content-Disposition头
+                    response.headers["Access-Control-Expose-Headers"] = "Content-Disposition"
+                    logger.info(f"返回文件: {original_filename}")
+                    logger.info(f"Content-Disposition: {response.headers.get('Content-Disposition')}")
                     return response
                 except Exception as e:
                     logger.error(f"返回文件失败: {str(e)}\n{traceback.format_exc()}")
@@ -318,30 +325,51 @@ def process_file():
                     for file_path in output_file:
                         if os.path.exists(file_path):
                             logger.info(f"添加文件到ZIP: {file_path}, 大小: {os.path.getsize(file_path)} 字节")
-                            # 使用ASCII安全的归档名
+                            # 直接使用原始文件名（支持 UTF-8）
                             filename = os.path.basename(file_path)
-                            try:
-                                filename.encode('latin-1')
-                            except UnicodeEncodeError:
-                                # 如果包含非ASCII字符，使用简单名称
-                                _, ext = os.path.splitext(filename)
-                                filename = f"file_{output_file.index(file_path)}{ext}"
                             zf.write(file_path, filename)
                         else:
                             logger.warning(f"要打包的文件不存在: {file_path}")
                 
+                # 获取ZIP文件大小（在seek之前）
+                zip_size = memory_file.tell()
+                logger.info(f"创建的ZIP文件大小: {zip_size} 字节")
+                
+                # 重置指针到文件开头
                 memory_file.seek(0)
-                zip_data = memory_file.getvalue()
-                logger.info(f"创建的ZIP文件大小: {len(zip_data)} 字节")
                 
-                # 使用ASCII安全的文件名
-                safe_filename = f"{tool or 'output'}_{datetime.now().strftime('%Y%m%d_%H%M%S')}.zip"
+                # 使用与输出文件一致的命名格式生成ZIP文件名
+                if input_path:
+                    base_name = os.path.splitext(os.path.basename(input_path))[0]
+                    current_time = datetime.now().strftime('%Y-%m-%d_%H-%M-%S')
+                    safe_filename = f"{base_name}_simple_chinese_output_{current_time}.zip"
+                else:
+                    current_time = datetime.now().strftime('%Y-%m-%d_%H-%M-%S')
+                    safe_filename = f"simple_chinese_output_{current_time}.zip"
+                
+                logger.info(f"返回ZIP文件: {safe_filename}")
+                
+                # 手动构建响应
+                response = make_response(memory_file.getvalue())
+                response.headers['Content-Type'] = 'application/zip'
+                
+                # 设置Content-Disposition，使用双格式兼容所有浏览器
+                try:
+                    # 检查文件名是否只包含ASCII字符
+                    safe_filename.encode('ascii')
+                    response.headers['Content-Disposition'] = f'attachment; filename="{safe_filename}"'
+                    logger.info(f"文件名使用ASCII编码: {safe_filename}")
+                except UnicodeEncodeError:
+                    # 包含中文，使用RFC 2231标准格式
+                    # filename*=UTF-8''编码后的文件名
+                    encoded_filename = quote(safe_filename)
+                    response.headers['Content-Disposition'] = f"attachment; filename*=UTF-8''{encoded_filename}"
+                    logger.info(f"设置UTF-8编码文件名: {encoded_filename}")
+                
+                # 确保前端JavaScript可以访问Content-Disposition头
+                response.headers['Access-Control-Expose-Headers'] = 'Content-Disposition'
+                logger.info(f"Content-Disposition已设置: {response.headers.get('Content-Disposition')}")
                 
-                response = make_response(zip_data)
-                response.headers['Content-Type'] = 'application/octet-stream'
-                response.headers['Content-Disposition'] = f'attachment; filename={safe_filename}'
-                response.headers["X-Content-Type-Options"] = "nosniff"
-                logger.info("返回ZIP文件")
                 return response
             except Exception as e:
                 logger.error(f"创建ZIP文件失败: {str(e)}\n{traceback.format_exc()}")
@@ -398,18 +426,18 @@ def get_website_config():
     })
 
 
-@app.route('/ads.txt', methods=['GET'])
-def serve_ads_txt():
-    """Serve ads.txt content configured in GUIConfig."""
-    content = str(getattr(GUIConfig, "ADS_TXT_LINES", ""))
+    @app.route('/ads.txt', methods=['GET'])
+    def serve_ads_txt():
+        """Serve ads.txt content configured in GUIConfig."""
+        content = str(getattr(GUIConfig, "ADS_TXT_LINES", ""))
 
-    if not content:
-        return Response("", mimetype='text/plain; charset=utf-8')
+        if not content:
+            return Response("", mimetype='text/plain; charset=utf-8')
 
-    if not content.endswith("\n"):
-        content += "\n"
+        if not content.endswith("\n"):
+            content += "\n"
 
-    return Response(content, mimetype='text/plain; charset=utf-8')
+        return Response(content, mimetype='text/plain; charset=utf-8')
 
 if __name__ == '__main__':
     logger.info("启动Flask应用")
